@@ -1,4 +1,4 @@
-__version__ = '0.1.0'
+__version__ = '0.1.1'
 
 ## Import packages
 import numpy as np
@@ -110,6 +110,8 @@ def IEM(trialbyvoxel,features,stim_max=180,is_circular=True,nfolds=10,
         The goodness of fit for each trial. That is, the correlation coefficient (Pearson's R) for each trial when performing the "correlation table" procedure to estimate each trial's predicted stimulus. You may choose to exclude some trials with the lowest confidences to potentially increase statistical power.
     recons : matrix (ndarray)
         Returns trial-by-trial reconstructions as a matrix of shape num_trials by stim_max. Note that these reconstructions are not aligned: the maximum point of a single trial reconstruction is generally associated with that trial's predicted color. You can visualize each trial reconstruction by plotting (e.g., plt.plot(recons[0,:]) for the first trial).
+    aligned_recons: matrix (ndarray)
+        Returns trial-by-trial reconstructions aligned such that the ground-truth stimuli are zero. That is, if reconstructions are perfect, each trial reconstruction should be centered at zero along the x-axis when plotted, e.g., plt.plot(aligned_recons[trial,:]).
 
     Example
     ----------
